==> open-xchange-mobile-api-facade_1.0.0.orig.tar.bz2: open-xchange-mobile-api-facade-1.0.0/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/models/Account.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.models;

import java.util.List;

import com.openexchange.mobile.api.facade.connectors.responses.mtos.AccountMto;
import com.openexchange.mobile.api.facade.connectors.responses.mtos.UserMto;

import lombok.Data;
import lombok.NonNull;

@Data
public class Account {

    @NonNull
    private final String id;

    @NonNull
    private final String accountName;

    private final String userName;

    private final String firstName;

    private final String lastName;

    @NonNull
    private final String primaryAddress;

    private final List<String> aliases;

    @NonNull
    private final List<Folder> folders;

    @NonNull
    private final StandardFolders standardFolders;

    public Account(AccountMto accountMto, UserMto userMto, List<Folder> folders) {
        id = accountMto.getId();
        accountName = accountMto.getAccountName();
        if (userMto != null) {
            userName = userMto.getDisplayName();
            firstName = userMto.getFirstName();
            lastName = userMto.getLastName();
        } else {
            userName = null;
            firstName = null;
            lastName = null;
        }
        primaryAddress = accountMto.getPrimaryAddress();
        aliases = accountMto.getAliases();
        /* Java8: Use with Java 8.
        List<FolderCto> folders = folderMtos.stream()
                .map(folderMto -> new FolderCto(folderMto.getId(), folderMto.getParentId(), folderMto.getName(), 0, 0, 0, 0))
                .collect(Collectors.toList());
        */
        this.folders = folders;
        standardFolders = createStandardFolders(folders);
    }

    private StandardFolders createStandardFolders(List<Folder> folders) {
        Folder inboxFolder = null;
        Folder archiveFolder = null;
        Folder draftsFolder = null;
        Folder sentFolder = null;
        Folder spamFolder = null;
        Folder trashFolder = null;

        for (Folder folder : folders) {
            switch (folder.getType()) {
            case INBOX:
                inboxFolder = folder;
                break;
            case ARCHIVE:
                archiveFolder = folder;
                break;
            case DRAFT:
                draftsFolder = folder;
                break;
            case SENT:
                sentFolder = folder;
                break;
            case SPAM:
                spamFolder = folder;
                break;
            case TRASH:
                trashFolder = folder;
                break;
            default:
                // Nothing to do.
                break;
            }
        }

        return new StandardFolders(draftsFolder, inboxFolder, sentFolder, spamFolder, trashFolder, archiveFolder);
    }

}

==> open-xchange-mobile-api-facade_1.0.1.orig.tar.bz2: open-xchange-mobile-api-facade-1.0.1/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/models/Account.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.models;

import java.util.List;

import com.openexchange.mobile.api.facade.connectors.responses.mtos.AccountMto;
import com.openexchange.mobile.api.facade.connectors.responses.mtos.UserMto;
import com.openexchange.mobile.api.facade.utils.StringUtils;

import lombok.Data;
import lombok.NonNull;

@Data
public class Account {

    @NonNull
    private final String id;

    @NonNull
    private final String accountName;

    private final String userName;

    private final String firstName;

    private final String lastName;

    @NonNull
    private final String primaryAddress;

    private final List<String> aliases;

    private final boolean canSend;

    @NonNull
    private final List<Folder> folders;

    @NonNull
    private final StandardFolders standardFolders;

    public Account(AccountMto accountMto, UserMto userMto, List<Folder> folders) {
        id = accountMto.getId();
        accountName = accountMto.getAccountName();
        String personalName = accountMto.getPersonalName();
        if (userMto != null) {
            userName = StringUtils.isEmpty(personalName) ? userMto.getDisplayName() : personalName;
            firstName = userMto.getFirstName();
            lastName = userMto.getLastName();
        } else {
            userName = personalName;
            firstName = null;
            lastName = null;
        }
        primaryAddress = accountMto.getPrimaryAddress();
        aliases = accountMto.getAliases();
        canSend = "0".equals(accountMto.getId()) || !StringUtils.isEmpty(accountMto.getTransportUrl());
        /* Java8: Use with Java 8.
        List<FolderCto> folders = folderMtos.stream()
                .map(folderMto -> new FolderCto(folderMto.getId(), folderMto.getParentId(), folderMto.getName(), 0, 0, 0, 0))
                .collect(Collectors.toList());
        */
        this.folders = folders;
        standardFolders = createStandardFolders(folders);
    }

    private StandardFolders createStandardFolders(List<Folder> folders) {
        Folder inboxFolder = null;
        Folder archiveFolder = null;
        Folder draftsFolder = null;
        Folder sentFolder = null;
        Folder spamFolder = null;
        Folder trashFolder = null;

        for (Folder folder : folders) {
            switch (folder.getType()) {
            case INBOX:
                inboxFolder = folder;
                break;
            case ARCHIVE:
                archiveFolder = folder;
                break;
            case DRAFT:
                draftsFolder = folder;
                break;
            case SENT:
                sentFolder = folder;
                break;
            case SPAM:
                spamFolder = folder;
                break;
            case TRASH:
                trashFolder = folder;
                break;
            default:
                // Nothing to do.
                break;
            }
        }

        return new StandardFolders(draftsFolder, inboxFolder, sentFolder, spamFolder, trashFolder, archiveFolder);
    }

}
